@@ -4,6 +4,7 @@ import jwt
 
 from atlassian_jwt_auth import algorithms
 from atlassian_jwt_auth import key
+from atlassian_jwt_auth import exceptions
 
 
 class JWTAuthVerifier(object):
@@ -16,6 +17,8 @@ class JWTAuthVerifier(object):
         self._seen_jti = OrderedDict()
         self._subject_should_match_issuer = kwargs.get(
             'subject_should_match_issuer', True)
+        self._check_jti_uniqueness = kwargs.get(
+            'check_jti_uniqueness', False)
 
     def verify_jwt(self, a_jwt, audience, leeway=0, **requests_kwargs):
         """Verify if the token is correct
@@ -60,21 +63,30 @@ class JWTAuthVerifier(object):
 
         if self._subject_should_match_issuer and (
                 claims.get('sub') and claims['iss'] != claims['sub']):
-            raise ValueError('Issuer does not match the subject.')
+            raise exceptions.SubjectDoesNotMatchIssuerException(
+                'Issuer does not match the subject.')
 
-        _aud = claims['aud']
+        _aud = claims.get('aud', None)
+        if _aud is None:
+            _msg = ("Claims validity, the aud claim must be provided and "
+                    "cannot be empty.")
+            raise KeyError(_msg)
         _exp = int(claims['exp'])
         _iat = int(claims['iat'])
         if _exp - _iat > 3600:
             _msg = ("Claims validity, '%s', exceeds the maximum 1 hour." %
                     (_exp - _iat))
             raise ValueError(_msg)
-
         _jti = claims['jti']
-        if _jti in self._seen_jti:
-            raise ValueError("The jti, '%s', has already been used." % _jti)
-        else:
-            self._seen_jti[_jti] = None
-            while len(self._seen_jti) > 1000:
-                self._seen_jti.popitem(last=False)
+        if self._check_jti_uniqueness:
+            self._check_jti(_jti)
         return claims
+
+    def _check_jti(self, jti):
+        """Checks that the given jti has not been already been used."""
+        if jti in self._seen_jti:
+            raise exceptions.JtiUniquenessException(
+                "The jti, '%s', has already been used." % jti)
+        self._seen_jti[jti] = None
+        while len(self._seen_jti) > 1000:
+            self._seen_jti.popitem(last=False)
